==> jc-1.4.0.tar.gz: java/sql/SQLWarning.h <==
// public class java.sql.SQLWarning

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class d5428f1f1b6fb1d3 java_sql_SQLException
// @dep_class 3ee7c8583e39880d java_sql_SQLWarning

// header file dependencies
// @dep_header java_sql_SQLException

#include "java/sql/SQLException.h"

#ifndef _JC_java_sql_SQLWarning_H_
#define _JC_java_sql_SQLWarning_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_sql_SQLWarning$object;

// Typedefs
typedef struct _jc_java_sql_SQLWarning$sub_refs	_jc_java_sql_SQLWarning$sub_refs;
typedef struct _jc_java_sql_SQLWarning$sub_nonrefs	_jc_java_sql_SQLWarning$sub_nonrefs;
typedef struct _jc_java_sql_SQLWarning$refs	_jc_java_sql_SQLWarning$refs;
typedef struct _jc_java_sql_SQLWarning$nonrefs	_jc_java_sql_SQLWarning$nonrefs;
typedef struct _jc_java_sql_SQLWarning$object	_jc_java_sql_SQLWarning$object;

typedef struct _jc_java_sql_SQLWarning$fields_struct	_jc_java_sql_SQLWarning$fields_struct;
typedef const struct _jc_java_sql_SQLWarning$vmethods	_jc_java_sql_SQLWarning$vmethods;
typedef const struct _jc_java_sql_SQLWarning$vtable	_jc_java_sql_SQLWarning$vtable;
typedef const struct _jc_java_sql_SQLWarning$vtype	_jc_java_sql_SQLWarning$vtype;

// Class fields structure
struct _jc_java_sql_SQLWarning$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_sql_SQLWarning$fields_struct _jc_java_sql_SQLWarning$class_fields;

// Constructors
extern void _jc_java_sql_SQLWarning$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_sql_SQLWarning$object *);
extern void _jc_java_sql_SQLWarning$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_sql_SQLWarning$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_sql_SQLWarning$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_sql_SQLWarning$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_sql_SQLWarning$method$_init$3814f9e0ae93d685(_jc_env *, struct _jc_java_sql_SQLWarning$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods
extern struct _jc_java_sql_SQLWarning$object *_jc_java_sql_SQLWarning$method$getNextWarning$ee0976d6c7d0eb35(_jc_env *, struct _jc_java_sql_SQLWarning$object *);
extern void _jc_java_sql_SQLWarning$method$setNextWarning$fe7c2ca6c49119b5(_jc_env *, struct _jc_java_sql_SQLWarning$object *, struct _jc_java_sql_SQLWarning$object *);

// Virtual method descriptors
extern _jc_method _jc_java_sql_SQLWarning$method_info$getNextWarning$ee0976d6c7d0eb35;
extern _jc_method _jc_java_sql_SQLWarning$method_info$setNextWarning$fe7c2ca6c49119b5;

// Virtual methods structure
struct _jc_java_sql_SQLWarning$vmethods {
	struct _jc_java_sql_SQLWarning$object	*(*getNextWarning$ee0976d6c7d0eb35)(_jc_env *, struct _jc_java_sql_SQLWarning$object *);
	void	(*setNextWarning$fe7c2ca6c49119b5)(_jc_env *, struct _jc_java_sql_SQLWarning$object *, struct _jc_java_sql_SQLWarning$object *);
};

// Vtable
struct _jc_java_sql_SQLWarning$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_sql_SQLException$vmethods	java_sql_SQLException;
	_jc_java_sql_SQLWarning$vmethods	java_sql_SQLWarning;
};

// Vtype
struct _jc_java_sql_SQLWarning$vtype {
	_jc_type			type;
	_jc_java_sql_SQLWarning$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_sql_SQLWarning$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_sql_SQLWarning$refs {
    _jc_java_sql_SQLWarning$sub_refs	java_sql_SQLWarning;
    _jc_java_sql_SQLException$sub_refs	java_sql_SQLException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_sql_SQLWarning$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_sql_SQLWarning$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_sql_SQLException$sub_nonrefs	java_sql_SQLException;
    _jc_java_sql_SQLWarning$sub_nonrefs	java_sql_SQLWarning;
};

// Object instance structure
struct _jc_java_sql_SQLWarning$object {
	_jc_java_sql_SQLWarning$refs	refs[0];
	_jc_word		lockword;
	_jc_java_sql_SQLWarning$vtype	*vtype;
	_jc_java_sql_SQLWarning$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_sql_SQLWarning$vtype _jc_java_sql_SQLWarning$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_sql_SQLWarning, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_sql_SQLWarning$class_object;

#endif	/* _JC_java_sql_SQLWarning_H_ */

==> jc-1.4.6.tar.gz: java/sql/SQLWarning.h <==
// public class java.sql.SQLWarning

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class d5428f1f1b6fb1d3 java_sql_SQLException
// @dep_class 3ee7c8583e39880d java_sql_SQLWarning

// header file dependencies
// @dep_header java_sql_SQLException

#include "java/sql/SQLException.h"

#ifndef _JC_java_sql_SQLWarning_H_
#define _JC_java_sql_SQLWarning_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_sql_SQLWarning$object;

// Typedefs
typedef struct _jc_java_sql_SQLWarning$sub_refs	_jc_java_sql_SQLWarning$sub_refs;
typedef struct _jc_java_sql_SQLWarning$sub_nonrefs	_jc_java_sql_SQLWarning$sub_nonrefs;
typedef struct _jc_java_sql_SQLWarning$refs	_jc_java_sql_SQLWarning$refs;
typedef struct _jc_java_sql_SQLWarning$nonrefs	_jc_java_sql_SQLWarning$nonrefs;
typedef struct _jc_java_sql_SQLWarning$object	_jc_java_sql_SQLWarning$object;

typedef struct _jc_java_sql_SQLWarning$fields_struct	_jc_java_sql_SQLWarning$fields_struct;
typedef const struct _jc_java_sql_SQLWarning$vmethods	_jc_java_sql_SQLWarning$vmethods;
typedef const struct _jc_java_sql_SQLWarning$vtable	_jc_java_sql_SQLWarning$vtable;
typedef const struct _jc_java_sql_SQLWarning$vtype	_jc_java_sql_SQLWarning$vtype;

// Class fields structure
struct _jc_java_sql_SQLWarning$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_sql_SQLWarning$fields_struct _jc_java_sql_SQLWarning$class_fields;

// Constructors
extern void _jc_java_sql_SQLWarning$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_sql_SQLWarning$object *) _JC_JCNI_ATTR;
extern void _jc_java_sql_SQLWarning$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_sql_SQLWarning$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_sql_SQLWarning$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_sql_SQLWarning$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_sql_SQLWarning$method$_init$3814f9e0ae93d685(_jc_env *, struct _jc_java_sql_SQLWarning$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_sql_SQLWarning$object *_jc_java_sql_SQLWarning$method$getNextWarning$ee0976d6c7d0eb35(_jc_env *, struct _jc_java_sql_SQLWarning$object *) _JC_JCNI_ATTR;
extern void _jc_java_sql_SQLWarning$method$setNextWarning$fe7c2ca6c49119b5(_jc_env *, struct _jc_java_sql_SQLWarning$object *, struct _jc_java_sql_SQLWarning$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_sql_SQLWarning$method_info$getNextWarning$ee0976d6c7d0eb35;
extern _jc_method _jc_java_sql_SQLWarning$method_info$setNextWarning$fe7c2ca6c49119b5;

// Virtual methods structure
struct _jc_java_sql_SQLWarning$vmethods {
	struct _jc_java_sql_SQLWarning$object	*(*getNextWarning$ee0976d6c7d0eb35)(_jc_env *, struct _jc_java_sql_SQLWarning$object *) _JC_JCNI_ATTR;
	void	(*setNextWarning$fe7c2ca6c49119b5)(_jc_env *, struct _jc_java_sql_SQLWarning$object *, struct _jc_java_sql_SQLWarning$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_sql_SQLWarning$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_sql_SQLException$vmethods	java_sql_SQLException;
	_jc_java_sql_SQLWarning$vmethods	java_sql_SQLWarning;
};

// Vtype
struct _jc_java_sql_SQLWarning$vtype {
	_jc_type			type;
	_jc_java_sql_SQLWarning$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_sql_SQLWarning$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_sql_SQLWarning$refs {
    _jc_java_sql_SQLWarning$sub_refs	java_sql_SQLWarning;
    _jc_java_sql_SQLException$sub_refs	java_sql_SQLException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_sql_SQLWarning$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_sql_SQLWarning$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_sql_SQLException$sub_nonrefs	java_sql_SQLException;
    _jc_java_sql_SQLWarning$sub_nonrefs	java_sql_SQLWarning;
};

// Object instance structure
struct _jc_java_sql_SQLWarning$object {
	_jc_java_sql_SQLWarning$refs	refs[0];
	_jc_word		lockword;
	_jc_java_sql_SQLWarning$vtype	*vtype;
	_jc_java_sql_SQLWarning$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_sql_SQLWarning$vtype _jc_java_sql_SQLWarning$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_sql_SQLWarning, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_sql_SQLWarning$class_object;

#endif	/* _JC_java_sql_SQLWarning_H_ */
